==> libvirt-glib-0.1.7p1.tgz: include/libvirt-gconfig-1.0/libvirt-gconfig/libvirt-gconfig-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __LIBVIRT_GCONFIG_ENUM_TYPES_H__
#define __LIBVIRT_GCONFIG_ENUM_TYPES_H__

#include <libvirt-gconfig/libvirt-gconfig.h>

G_BEGIN_DECLS

/* enumerations from "./libvirt-gconfig-domain.h" */
GType gvir_config_domain_virt_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_VIRT_TYPE (gvir_config_domain_virt_type_get_type ())
GType gvir_config_domain_lifecycle_event_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_LIFECYCLE_EVENT (gvir_config_domain_lifecycle_event_get_type ())
GType gvir_config_domain_lifecycle_action_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_LIFECYCLE_ACTION (gvir_config_domain_lifecycle_action_get_type ())

/* enumerations from "./libvirt-gconfig-domain-channel.h" */
GType gvir_config_domain_channel_target_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CHANNEL_TARGET_TYPE (gvir_config_domain_channel_target_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-clock.h" */
GType gvir_config_domain_clock_offset_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CLOCK_OFFSET (gvir_config_domain_clock_offset_get_type ())

/* enumerations from "./libvirt-gconfig-domain-console.h" */
GType gvir_config_domain_console_target_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CONSOLE_TARGET_TYPE (gvir_config_domain_console_target_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-controller-usb.h" */
GType gvir_config_domain_controller_usb_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CONTROLLER_USB_MODEL (gvir_config_domain_controller_usb_model_get_type ())

/* enumerations from "./libvirt-gconfig-domain-cpu.h" */
GType gvir_config_domain_cpu_match_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CPU_MATCH_POLICY (gvir_config_domain_cpu_match_policy_get_type ())
GType gvir_config_domain_cpu_mode_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CPU_MODE (gvir_config_domain_cpu_mode_get_type ())

/* enumerations from "./libvirt-gconfig-domain-cpu-feature.h" */
GType gvir_config_domain_cpu_feature_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CPU_FEATURE_POLICY (gvir_config_domain_cpu_feature_policy_get_type ())

/* enumerations from "./libvirt-gconfig-domain-disk.h" */
GType gvir_config_domain_disk_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_TYPE (gvir_config_domain_disk_type_get_type ())
GType gvir_config_domain_disk_bus_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_BUS (gvir_config_domain_disk_bus_get_type ())
GType gvir_config_domain_disk_cache_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_CACHE_TYPE (gvir_config_domain_disk_cache_type_get_type ())
GType gvir_config_domain_disk_guest_device_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_GUEST_DEVICE_TYPE (gvir_config_domain_disk_guest_device_type_get_type ())
GType gvir_config_domain_disk_snapshot_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_SNAPSHOT_TYPE (gvir_config_domain_disk_snapshot_type_get_type ())
GType gvir_config_domain_disk_startup_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_STARTUP_POLICY (gvir_config_domain_disk_startup_policy_get_type ())
GType gvir_config_domain_disk_format_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_FORMAT (gvir_config_domain_disk_format_get_type ())

/* enumerations from "./libvirt-gconfig-domain-filesys.h" */
GType gvir_config_domain_filesys_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_FILESYS_TYPE (gvir_config_domain_filesys_type_get_type ())
GType gvir_config_domain_filesys_access_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_FILESYS_ACCESS_TYPE (gvir_config_domain_filesys_access_type_get_type ())
GType gvir_config_domain_filesys_driver_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_FILESYS_DRIVER_TYPE (gvir_config_domain_filesys_driver_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-graphics-spice.h" */
GType gvir_config_domain_graphics_spice_image_compression_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_GRAPHICS_SPICE_IMAGE_COMPRESSION (gvir_config_domain_graphics_spice_image_compression_get_type ())

/* enumerations from "./libvirt-gconfig-domain-input.h" */
GType gvir_config_domain_input_device_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_INPUT_DEVICE_TYPE (gvir_config_domain_input_device_type_get_type ())
GType gvir_config_domain_input_bus_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_INPUT_BUS (gvir_config_domain_input_bus_get_type ())

/* enumerations from "./libvirt-gconfig-domain-interface.h" */
GType gvir_config_domain_interface_link_state_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_INTERFACE_LINK_STATE (gvir_config_domain_interface_link_state_get_type ())

/* enumerations from "./libvirt-gconfig-domain-memballoon.h" */
GType gvir_config_domain_memballoon_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_MEMBALLOON_MODEL (gvir_config_domain_memballoon_model_get_type ())

/* enumerations from "./libvirt-gconfig-domain-os.h" */
GType gvir_config_domain_os_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_OS_TYPE (gvir_config_domain_os_type_get_type ())
GType gvir_config_domain_os_sm_bios_mode_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_OS_SM_BIOS_MODE (gvir_config_domain_os_sm_bios_mode_get_type ())
GType gvir_config_domain_os_boot_device_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_OS_BOOT_DEVICE (gvir_config_domain_os_boot_device_get_type ())

/* enumerations from "./libvirt-gconfig-domain-redirdev.h" */
GType gvir_config_domain_redirdev_bus_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_REDIRDEV_BUS (gvir_config_domain_redirdev_bus_get_type ())

/* enumerations from "./libvirt-gconfig-domain-seclabel.h" */
GType gvir_config_domain_seclabel_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SECLABEL_TYPE (gvir_config_domain_seclabel_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-snapshot.h" */
GType gvir_config_domain_snapshot_domain_state_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SNAPSHOT_DOMAIN_STATE (gvir_config_domain_snapshot_domain_state_get_type ())
GType gvir_config_domain_snapshot_memory_state_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SNAPSHOT_MEMORY_STATE (gvir_config_domain_snapshot_memory_state_get_type ())

/* enumerations from "./libvirt-gconfig-domain-sound.h" */
GType gvir_config_domain_sound_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SOUND_MODEL (gvir_config_domain_sound_model_get_type ())

/* enumerations from "./libvirt-gconfig-domain-timer.h" */
GType gvir_config_domain_timer_tick_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_TIMER_TICK_POLICY (gvir_config_domain_timer_tick_policy_get_type ())

/* enumerations from "./libvirt-gconfig-domain-video.h" */
GType gvir_config_domain_video_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_VIDEO_MODEL (gvir_config_domain_video_model_get_type ())

/* enumerations from "./libvirt-gconfig-storage-pool.h" */
GType gvir_config_storage_pool_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_STORAGE_POOL_TYPE (gvir_config_storage_pool_type_get_type ())
G_END_DECLS

#endif /* __LIBVIRT_GCONFIG_ENUM_TYPES_H__ */

/* Generated data ends here */

==> libvirt-glib-1.0.0.tgz: include/libvirt-gconfig-1.0/libvirt-gconfig/libvirt-gconfig-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __LIBVIRT_GCONFIG_ENUM_TYPES_H__
#define __LIBVIRT_GCONFIG_ENUM_TYPES_H__

#include <libvirt-gconfig/libvirt-gconfig.h>

G_BEGIN_DECLS

/* enumerations from "./libvirt-gconfig-domain-channel.h" */
GType gvir_config_domain_channel_target_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CHANNEL_TARGET_TYPE (gvir_config_domain_channel_target_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-clock.h" */
GType gvir_config_domain_clock_offset_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CLOCK_OFFSET (gvir_config_domain_clock_offset_get_type ())

/* enumerations from "./libvirt-gconfig-domain-console.h" */
GType gvir_config_domain_console_target_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CONSOLE_TARGET_TYPE (gvir_config_domain_console_target_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-controller-usb.h" */
GType gvir_config_domain_controller_usb_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CONTROLLER_USB_MODEL (gvir_config_domain_controller_usb_model_get_type ())

/* enumerations from "./libvirt-gconfig-domain-cpu-feature.h" */
GType gvir_config_domain_cpu_feature_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CPU_FEATURE_POLICY (gvir_config_domain_cpu_feature_policy_get_type ())

/* enumerations from "./libvirt-gconfig-domain-cpu.h" */
GType gvir_config_domain_cpu_match_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CPU_MATCH_POLICY (gvir_config_domain_cpu_match_policy_get_type ())
GType gvir_config_domain_cpu_mode_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_CPU_MODE (gvir_config_domain_cpu_mode_get_type ())

/* enumerations from "./libvirt-gconfig-domain-disk-driver.h" */
GType gvir_config_domain_disk_cache_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_CACHE_TYPE (gvir_config_domain_disk_cache_type_get_type ())
GType gvir_config_domain_disk_format_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_FORMAT (gvir_config_domain_disk_format_get_type ())
GType gvir_config_domain_disk_driver_error_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_DRIVER_ERROR_POLICY (gvir_config_domain_disk_driver_error_policy_get_type ())
GType gvir_config_domain_disk_driver_io_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_DRIVER_IO_POLICY (gvir_config_domain_disk_driver_io_policy_get_type ())
GType gvir_config_domain_disk_driver_discard_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_DRIVER_DISCARD (gvir_config_domain_disk_driver_discard_get_type ())

/* enumerations from "./libvirt-gconfig-domain-disk.h" */
GType gvir_config_domain_disk_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_TYPE (gvir_config_domain_disk_type_get_type ())
GType gvir_config_domain_disk_bus_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_BUS (gvir_config_domain_disk_bus_get_type ())
GType gvir_config_domain_disk_guest_device_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_GUEST_DEVICE_TYPE (gvir_config_domain_disk_guest_device_type_get_type ())
GType gvir_config_domain_disk_snapshot_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_SNAPSHOT_TYPE (gvir_config_domain_disk_snapshot_type_get_type ())
GType gvir_config_domain_disk_startup_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_DISK_STARTUP_POLICY (gvir_config_domain_disk_startup_policy_get_type ())

/* enumerations from "./libvirt-gconfig-domain-filesys.h" */
GType gvir_config_domain_filesys_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_FILESYS_TYPE (gvir_config_domain_filesys_type_get_type ())
GType gvir_config_domain_filesys_access_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_FILESYS_ACCESS_TYPE (gvir_config_domain_filesys_access_type_get_type ())
GType gvir_config_domain_filesys_driver_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_FILESYS_DRIVER_TYPE (gvir_config_domain_filesys_driver_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-graphics-spice.h" */
GType gvir_config_domain_graphics_spice_image_compression_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_GRAPHICS_SPICE_IMAGE_COMPRESSION (gvir_config_domain_graphics_spice_image_compression_get_type ())

/* enumerations from "./libvirt-gconfig-domain-input.h" */
GType gvir_config_domain_input_device_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_INPUT_DEVICE_TYPE (gvir_config_domain_input_device_type_get_type ())
GType gvir_config_domain_input_bus_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_INPUT_BUS (gvir_config_domain_input_bus_get_type ())

/* enumerations from "./libvirt-gconfig-domain-interface.h" */
GType gvir_config_domain_interface_link_state_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_INTERFACE_LINK_STATE (gvir_config_domain_interface_link_state_get_type ())

/* enumerations from "./libvirt-gconfig-domain-memballoon.h" */
GType gvir_config_domain_memballoon_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_MEMBALLOON_MODEL (gvir_config_domain_memballoon_model_get_type ())

/* enumerations from "./libvirt-gconfig-domain-os.h" */
GType gvir_config_domain_os_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_OS_TYPE (gvir_config_domain_os_type_get_type ())
GType gvir_config_domain_os_sm_bios_mode_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_OS_SM_BIOS_MODE (gvir_config_domain_os_sm_bios_mode_get_type ())
GType gvir_config_domain_os_boot_device_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_OS_BOOT_DEVICE (gvir_config_domain_os_boot_device_get_type ())

/* enumerations from "./libvirt-gconfig-domain-redirdev.h" */
GType gvir_config_domain_redirdev_bus_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_REDIRDEV_BUS (gvir_config_domain_redirdev_bus_get_type ())

/* enumerations from "./libvirt-gconfig-domain-seclabel.h" */
GType gvir_config_domain_seclabel_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SECLABEL_TYPE (gvir_config_domain_seclabel_type_get_type ())

/* enumerations from "./libvirt-gconfig-domain-snapshot.h" */
GType gvir_config_domain_snapshot_domain_state_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SNAPSHOT_DOMAIN_STATE (gvir_config_domain_snapshot_domain_state_get_type ())
GType gvir_config_domain_snapshot_memory_state_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SNAPSHOT_MEMORY_STATE (gvir_config_domain_snapshot_memory_state_get_type ())

/* enumerations from "./libvirt-gconfig-domain-sound.h" */
GType gvir_config_domain_sound_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_SOUND_MODEL (gvir_config_domain_sound_model_get_type ())

/* enumerations from "./libvirt-gconfig-domain-timer.h" */
GType gvir_config_domain_timer_tick_policy_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_TIMER_TICK_POLICY (gvir_config_domain_timer_tick_policy_get_type ())

/* enumerations from "./libvirt-gconfig-domain-video.h" */
GType gvir_config_domain_video_model_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_VIDEO_MODEL (gvir_config_domain_video_model_get_type ())

/* enumerations from "./libvirt-gconfig-domain.h" */
GType gvir_config_domain_virt_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_VIRT_TYPE (gvir_config_domain_virt_type_get_type ())
GType gvir_config_domain_lifecycle_event_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_LIFECYCLE_EVENT (gvir_config_domain_lifecycle_event_get_type ())
GType gvir_config_domain_lifecycle_action_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_DOMAIN_LIFECYCLE_ACTION (gvir_config_domain_lifecycle_action_get_type ())

/* enumerations from "./libvirt-gconfig-storage-pool.h" */
GType gvir_config_storage_pool_type_get_type (void) G_GNUC_CONST;
#define GVIR_CONFIG_TYPE_STORAGE_POOL_TYPE (gvir_config_storage_pool_type_get_type ())
G_END_DECLS

#endif /* __LIBVIRT_GCONFIG_ENUM_TYPES_H__ */

/* Generated data ends here */
